/*
    Inlcude file for libgaudio (gaudio.c)

    The contents of this file are subject to the Mozilla Public
    License Version 1.1 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a copy of
    the License at http://www.mozilla.org/MPL/
    
    Software distributed under the License is distributed on an "AS
    IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
    implied. See the License for the specific language governing
    rights and limitations under the License.
   
    The Original Code is the libgaudio sound mixing library.
    
    The Initial Developer of the Original Code is A. Schiffler.  
    Portions created by A. Schiffler are Copyright (C) 1999-2000
    A. Schiffler.  All Rights Reserved.
    
    Contributor(s): A. Schiffler <aschiffler@home.com>
                                                                                                                dnl 
    Alternatively, the contents of this file may be used under the
    terms of the GNU General Public License Version 2 or later (the
    "GPL"), in which case the provisions of the GPL are applicable 
    instead of those above.  If you wish to allow use of your 
    version of this file only under the terms of the GPL and not to
    allow others to use your version of this file under the MPL,
    indicate your decision by deleting the provisions above and
    replace them with the notice and other provisions required by
    the GPL.  If you do not delete the provisions above, a recipient
    may use your version of this file under either the MPL or the
    GPL.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    To contact the author try:
    |  Andreas Schiffler                    aschiffler@home.com  |
    |  Senior Systems Engineer  -  Deskplayer.Com Inc., Buffalo  |
    |  4707 Eastwood Cres., Niagara Falls, Ont  L2E 1B4, Canada  |
    |  +1-905-371-3652 (private)  -  +1-905-371-8834 (work/fax)  |

*/

/* Gameaudio defines */


#include <stdio.h>
#include <pthread.h>

#include <sndfile.h>

#define AUDIO_BUFFER_SIZE	4096		/* In bytes */
#define MAX_NUM_SAMPLES		256
#define MAX_NUM_PLAYING		12
#define BYTES_PER_SAMPLE	4
#define GAUDIO_RATE         44100


struct ga_sample
{
    short* data;
    short* dataendmarker;
    int numsamples;
};


struct ga_playing
{
    int sample_id;
    int playing_id;
    short* rootpos;
    short* curpos;
    short* endpos;
    int a,b;
    int repeat_count;
};


struct gameaudio
{
    int audio_fd;
    FILE* background_stream;
    int background_stream_bytes;
    int paused;
    
    int num_samples;
    struct ga_sample samples[ MAX_NUM_SAMPLES ];
    
    int num_playing;
    int playing_count;
    struct ga_playing playing[ MAX_NUM_PLAYING ];
    
    pthread_mutex_t buffer_mutex;
    pthread_t audio_thread;
};


/* Macros */

#define audioValid(ga)  (ga->audio_fd > -1)
#define audioPaused(ga) (ga->paused != 0)

		
/* Prototypes */

#ifdef __cplusplus
extern "C"
{
#endif

int startAudio( struct gameaudio* ga, const char* device_name );
int stopAudio( struct gameaudio* ga );
void pauseAudio( struct gameaudio* ga );
void unpauseAudio( struct gameaudio* ga );

int loadSample( struct gameaudio* ga, const char* filename );
int loadSampleLeft( struct gameaudio* ga, const char* filename );
int loadSampleRight( struct gameaudio* ga, const char* filename );

int copySample( struct gameaudio* ga, void* data, int bytelen );
int copySampleLeft( struct gameaudio* ga, void* data, int bytelen );
int copySampleRight( struct gameaudio* ga, void* data, int bytelen );

int playSample( struct gameaudio* ga, int sample_id, int repeat_count );
void ctrlSample( struct gameaudio* ga, int sample_id, int volume, int pan);
void stopSample( struct gameaudio* ga, int sample_id );
void stopAllSamples( struct gameaudio* ga );

void playBackground( struct gameaudio* ga, const char* filename );
void stopBackground( struct gameaudio* ga );
int checkBackground( struct gameaudio* ga );
float timeBackground( struct gameaudio* ga );

#ifdef __cplusplus
}
#endif 
