/*
    Program: halloween - sample program for libgaudio

    The contents of this file are subject to the Mozilla Public
    License Version 1.1 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a copy of
    the License at http://www.mozilla.org/MPL/
    
    Software distributed under the License is distributed on an "AS
    IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
    implied. See the License for the specific language governing
    rights and limitations under the License.
   
    The Original Code is the libgaudio sound mixing library.
    
    The Initial Developer of the Original Code is A. Schiffler.  
    Portions created by A. Schiffler are Copyright (C) 1999-2000
    A. Schiffler.  All Rights Reserved.
    
    Contributor(s): A. Schiffler <aschiffler@home.com>
                                                                                                                dnl 
    Alternatively, the contents of this file may be used under the
    terms of the GNU General Public License Version 2 or later (the
    "GPL"), in which case the provisions of the GPL are applicable 
    instead of those above.  If you wish to allow use of your 
    version of this file only under the terms of the GPL and not to
    allow others to use your version of this file under the MPL,
    indicate your decision by deleting the provisions above and
    replace them with the notice and other provisions required by
    the GPL.  If you do not delete the provisions above, a recipient
    may use your version of this file under either the MPL or the
    GPL.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    To contact the author try:
    |  Andreas Schiffler                    aschiffler@home.com  |
    |  Senior Systems Engineer  -  Deskplayer.Com Inc., Buffalo  |
    |  4707 Eastwood Cres., Niagara Falls, Ont  L2E 1B4, Canada  |
    |  +1-905-371-3652 (private)  -  +1-905-371-8834 (work/fax)  |
*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "gaudio.h"     /* libgaudio defines */

/* Define maximum delay (in seconds) between sample starts */

#define DELAY 	8


/* The main halloween loop ... */

int main (int argc, char *argv[])
{
    int i,j;
    
    /* libgaudio handle */
    struct gameaudio ga;

    /* sample references */
    int ids[1024];
    int numids;
   
    /* Check number of command line parameters and print help */
    if (argc<2) {
    	fprintf (stderr, "Random WAV playback for scary effects during Halloween!\n");
    	fprintf (stderr, "Usage: %s sample1.wav sample2.wav ...\n",argv[0]);
    	exit(-1);
    }
     
    /* Randomize */
    srand(time(NULL));
    
    /* Open soundcard device */
    printf("Opening device ...\n");
    if( startAudio( &ga, "/dev/dsp" ) < 0 )
        exit(-1);

    /* Determine number if IDs */
    numids=argc-1;
    
    /* Pre-cache samples ... keeping id's */
    printf( "Precaching %i samples ...\n",numids );
    for (i=1; i<=numids; i++) {
     printf ("Loading %s ...\n",argv[i]);
     ids[i]=loadSample (&ga, argv[i]);
    }

    while (1) {
     j=ids[rand() % numids];
     printf ("Playing %s ...\n",argv[j+1]);
     playSample( &ga, j, 1 );
     ctrlSample( &ga, j, 128, 128 );
     sleep(rand() % DELAY);
    }    

    /* Shut audio down */
    stopAudio( &ga ); 

    return( 0 );
}


/*EOF*/
