/*
    Program: testaudio - sample program for libgaudio

    The contents of this file are subject to the Mozilla Public
    License Version 1.1 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a copy of
    the License at http://www.mozilla.org/MPL/
    
    Software distributed under the License is distributed on an "AS
    IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
    implied. See the License for the specific language governing
    rights and limitations under the License.
   
    The Original Code is the libgaudio sound mixing library.
    
    The Initial Developer of the Original Code is A. Schiffler.  
    Portions created by A. Schiffler are Copyright (C) 1999-2000
    A. Schiffler.  All Rights Reserved.
    
    Contributor(s): A. Schiffler <aschiffler@home.com>
                    K. Robbillard <krobillard@home.com>                 
                                                                                                                dnl 
    Alternatively, the contents of this file may be used under the
    terms of the GNU General Public License Version 2 or later (the
    "GPL"), in which case the provisions of the GPL are applicable 
    instead of those above.  If you wish to allow use of your 
    version of this file only under the terms of the GPL and not to
    allow others to use your version of this file under the MPL,
    indicate your decision by deleting the provisions above and
    replace them with the notice and other provisions required by
    the GPL.  If you do not delete the provisions above, a recipient
    may use your version of this file under either the MPL or the
    GPL.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    To contact the author try:
    |  Andreas Schiffler                    aschiffler@home.com  |
    |  Senior Systems Engineer  -  Deskplayer.Com Inc., Buffalo  |
    |  4707 Eastwood Cres., Niagara Falls, Ont  L2E 1B4, Canada  |
    |  +1-905-371-3652 (private)  -  +1-905-371-8834 (work/fax)  |

*/

#include <stdio.h>
#include <unistd.h>

#include "gaudio.h"     /* libgaudio defines */

void printMenu()
{
    printf( "Command Menu:\n"
            "\t? - print menu\n"
            "\t1 - play sample 1\n"
            "\t2 - play sample 2\n"
            "\t3 - play sample 3\n"
            "\t4 - play sample 4\n"
            "\t5 - play sample 1 with only left channel loaded\n"
            "\t6 - play sample 2 with only right channel loaded\n"
            "\tl - play sample 1 in a loop\n"
            "\tL - play sample 2 in a loop\n"
            "\tp - play sample 3 and 4 panning\n"
            "\tv - play sample 1 changing volume\n"
            "\tP - play sample 3 changing volume and panning\n" 
            "\tM - mute audio\n"
            "\tU - un-mute audio\n"
            "\ts - stop all samples\n"
#ifdef MP3_IN_TEST            
            "\tm - start/stop background music (requires SampleMP3/Sample.mp3 file)\n"
            "\tt - print time of background music playback\n"
#endif
            "\tq - quit demo\n\n" );
}

int main()
{
    int c,i,j;

    /* libgaudio handle */
    struct gameaudio ga;

    /* sample references */
    int fire_id;
    int appear_id;
    int left_id;
    int right_id;
    int fire_left_id;
    int appear_right_id;
    
    /* open soundcard device */
    printf("Opening device ...\n");
    if( startAudio( &ga, "/dev/dsp" ) < 0 )
        exit(-1);

    /* pre-cache samples ... keeping id's */
    printf( "Precaching samples ...\n" );
    fire_id   = loadSample( &ga, "Fire.wav" );
    appear_id = loadSample( &ga, "Appear.wav" );
    left_id   = loadSample( &ga, "Left.wav" );
    right_id  = loadSample( &ga, "Right.wav" );
    fire_left_id   = loadSampleLeft( &ga, "Fire.wav" );
    appear_right_id = loadSampleRight( &ga, "Appear.wav" );

    /* User interface loop */
    printMenu();
    c = 0;
    while( c != 'q' )
    {
        c = getchar();
        switch( c )
        {
            case '1':
                printf( "Playing fire sound once ...\n" );
                playSample( &ga, fire_id, 1 );
                break;

            case '2':
                printf( "Playing appear sound once ...\n" );
                playSample( &ga, appear_id, 1 );
                break;

            case '3':
                printf( "Playing left sound once ...\n" );
                playSample( &ga, left_id, 1 );
                break;

            case '4':
                printf( "Playing right sound once ...\n" );
                playSample( &ga, right_id, 1 );
                break;

            case '5':
                printf( "Playing fire sound (left channel) once ...\n" );
                playSample( &ga, fire_left_id, 1 );
                break;

            case '6':
                printf( "Playing appear sound (right channel) once ...\n" );
                playSample( &ga, appear_right_id, 1 );
                break;

#ifdef MP3_IN_TEST            

            case 'm':
                if( checkBackground( &ga ) )
                {
                    printf( "Stopping background MP3 ...\n" );
                    stopBackground( &ga );
                }
                else
                {
                    printf( "Starting background MP3 ...\n" );
                    playBackground( &ga, "SampleMP3/Sample.mp3" );
                }
                break;

            case 't':
                printf( "Background time is %.2f sec.\n", timeBackground(&ga));
                break;

#endif

            case 'l':
                printf( "Playing fire sound in a loop ...\n" ); 
                playSample( &ga, fire_id, 0 );
                break;

            case 'L':
                printf( "Playing appear sound in a loop ...\n" ); 
                playSample( &ga, appear_id, 0 );
                break;

            case 'p':
                printf( "Playing left and right sound panning ... please wait.\n" ); 
                playSample( &ga, left_id, 0 );
                for (i=0; i<=256; i += 16) {
                 printf ("Pan value set to %i\n",i);
                 ctrlSample ( &ga, left_id, 256, i);
                 usleep (500000);
                }
                sleep (1);
                stopSample( &ga, left_id );
                playSample( &ga, right_id, 0 );
                for (i=0; i<=256; i += 16) {
                 printf ("Pan value set to %i\n",i);
                 ctrlSample ( &ga, right_id, 256, i);
                 usleep (500000);
                }
                sleep(1);
                stopSample( &ga, right_id );
                break;

            case 'v':
                printf( "Playing fire sound changing volume ... please wait.\n" ); 
                playSample( &ga, fire_id, 0 );
                for (i=0; i<=256; i += 16) {
                 printf ("Volume value set to %i\n",i);
                 ctrlSample ( &ga, fire_id, i, 0);
                 usleep (500000);
                }
                sleep (1);
                stopSample( &ga, fire_id );
                break;

            case 'P':
                printf( "Playing left sound changing volume and panning ... please wait.\n" ); 
                playSample( &ga, left_id, 0 );
                for (i=0; i<=256; i += 8) {
                 if (i<128) { 
                  j=2*i; 
                 } else {
                  j=256-2*(i-128); 
                 } 
                 printf ("Pan value set to %i, Volume value set to %i\n",i,j);
                 ctrlSample ( &ga, left_id, j, i);
                 usleep (500000);
                }
                sleep (1);
                stopSample( &ga, left_id );
                break;

            case 's':
                printf( "Stopping all effects ...\n" );
                stopAllSamples( &ga );
                break;

            case 'M':
                printf( "Mute sound\n" );
                pauseAudio( &ga );
                break;

            case 'U':
                printf( "Un-mute sound\n" );
                unpauseAudio( &ga );
                break;

            case 'h':
            case '?':
                printMenu();
                break;
        }
    }

    /* Shut audio down */
    stopAudio( &ga ); 

    return( 0 );
}


/*EOF*/
